@@ -3,6 +3,7 @@ The default group of operations that pyflexebs has
 """
 import logging
 import os
+import subprocess
 import sys
 import time
 
@@ -83,6 +84,11 @@ def daemon() -> None:
                         p.device,
                         p.mountpoint,
                     ))
+                    logger.info("percent is {}, total is {}, used is {}".format(
+                        psutil.disk_usage(p.mountpoint).percent,
+                        psutil.disk_usage(p.mountpoint).total,
+                        psutil.disk_usage(p.mountpoint).used,
+                    ))
                     enlarge_volume(p, device_to_volume, ec2_client)
             if ConfigAlgo.watermark_min is not None:
                 if psutil.disk_usage(p.mountpoint).percent <= ConfigAlgo.watermark_min:
@@ -90,6 +96,11 @@ def daemon() -> None:
                         p.device,
                         p.mountpoint,
                     ))
+                    logger.info("percent is {}, total is {}, used is {}".format(
+                        psutil.disk_usage(p.mountpoint).percent,
+                        psutil.disk_usage(p.mountpoint).total,
+                        psutil.disk_usage(p.mountpoint).used,
+                    ))
         time.sleep(ConfigAlgo.interval)
 
 
@@ -110,22 +121,38 @@ def enlarge_volume(p, device_to_volume, ec2):
         return
     volume = device_to_volume[p.device]
     volume_id = volume.id
-    volume_size = volume.size
+    # volume_size = volume.size
+    volume_size = psutil.disk_usage(p.mountpoint).total
     volume_size_float = float(volume_size)
     volume_size_float /= 100
     volume_size_float *= (100+ConfigAlgo.increase_percent)
     new_size = int(volume_size_float)
-    print("trying to increase size to [{}]".format(new_size))
-    # noinspection PyBroadException
-    try:
-        result = ec2.modify_volume(
-            DryRun=ConfigAlgo.dryrun,
-            VolumeId=volume_id,
-            Size=new_size,
-        )
-        print("Success in increasing size [{}]".format(result))
-    except Exception as e:
-        print("Failure in increasing size [{}]".format(e))
+    if volume.size < new_size:
+        print("trying to increase size to [{}]".format(new_size))
+        # noinspection PyBroadException
+        try:
+            result = ec2.modify_volume(
+                DryRun=ConfigAlgo.dryrun,
+                VolumeId=volume_id,
+                Size=new_size,
+            )
+            print("Success in increasing size [{}]".format(result))
+        except Exception as e:
+            print("Failure in increasing size [{}]".format(e))
+    # resize the file system
+    print("doing [{}] extension", format(p.fstype))
+    if p.fstype == "ext4":
+        subprocess.check_call([
+            "resize2fs",
+            p.device,
+        ])
+    if p.fstype == "xfs":
+        print("doing ext4 extension")
+        subprocess.check_call([
+            "xfs_growfs",
+            "-d",
+            p.mountpoint,
+        ])
 
 
 @register_endpoint(
